=========
Dye Score
=========

.. image:: https://readthedocs.org/projects/dyescore/badge/?version=latest
    :target: https://dyescore.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://travis-ci.org/mozilla/dye-score.svg?branch=master
    :target: https://travis-ci.org/mozilla/dye-score


Utilities to build the dye-score metric from OpenWPM_ javascript call data.


* GitHub repo: https://github.com/mozilla/dye-score/
* Documentation: https://dyescore.readthedocs.io/
* Free software: Mozilla Public License

Quickstart
----------

Install dye score: ``pip install dye-score``

Review usage notebook: https://github.com/mozilla/dye-score/blob/master/docs/usage.ipynb

.. _OpenWPM: https://github.com/mozilla/openwpm
